@@ -3,7 +3,6 @@ package main
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"strings"
@@ -15,7 +14,7 @@ import (
 )
 
 // Version is a version number.
-var version = "0.6.6"
+var version = "0.6.7"
 
 // UI is a user interface which is a global variable for mocking.
 var UI cli.Ui
@@ -58,7 +57,7 @@ func logOutput() io.Writer {
 	minLevel := os.Getenv("TFUPDATE_LOG")
 
 	// default log writer is null device.
-	writer := ioutil.Discard
+	writer := io.Discard
 	if minLevel != "" {
 		writer = os.Stderr
 	}
